package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EStoreMapper;
import com.ruoyi.system.domain.store.EStore;
import com.ruoyi.system.domain.store.EStoreVO;
import com.ruoyi.system.domain.store.EStoreQuery;
import com.ruoyi.system.service.IEStoreService;

/**
 * 店铺Service业务层处理
 *
 * @author qzz
 * @date 2024-11-20
 */
@Service
public class EStoreServiceImpl implements IEStoreService
{
    @Autowired
    private EStoreMapper eStoreMapper;

    /**
     * 查询店铺
     *
     * @param storeId 店铺主键
     * @return 店铺
     */
    @Override
    public EStoreVO selectEStoreByStoreId(Long storeId)
    {
        return eStoreMapper.selectEStoreByStoreId(storeId);
    }

    /**
     * 查询店铺列表
     *
     * @param eStore 店铺
     * @return 店铺
     */
    @Override
    public List<EStoreVO> selectEStoreList(EStoreQuery eStore)
    {
        return eStoreMapper.selectEStoreList(eStore);
    }

    /**
     * 新增店铺
     *
     * @param eStore 店铺
     * @return 结果
     */
    @Override
    public int insertEStore(EStore eStore)
    {
        eStore.setCreateTime(DateUtils.getNowDate());
        return eStoreMapper.insertEStore(eStore);
    }

    /**
     * 修改店铺
     *
     * @param eStore 店铺
     * @return 结果
     */
    @Override
    public int updateEStore(EStore eStore)
    {
        eStore.setUpdateTime(DateUtils.getNowDate());
        return eStoreMapper.updateEStore(eStore);
    }

    /**
     * 批量删除店铺
     *
     * @param storeIds 需要删除的店铺主键
     * @return 结果
     */
    @Override
    public int deleteEStoreByStoreIds(Long[] storeIds)
    {
        return eStoreMapper.deleteEStoreByStoreIds(storeIds);
    }

    /**
     * 删除店铺信息
     *
     * @param storeId 店铺主键
     * @return 结果
     */
    @Override
    public int deleteEStoreByStoreId(Long storeId)
    {
        return eStoreMapper.deleteEStoreByStoreId(storeId);
    }
}
